@@ -150,7 +150,7 @@ class HealthchecksService(BaseServices):
     def findProject(self, browser, project):
         projectLink = None
         for link in browser.page.select('a'):
-            if link.text.strip() == project:
+            if project in link.text.strip():
                 projectLink = link.attrs['href']
         return projectLink
         
